package com.platform.demo.cron;

import java.util.*;
import com.platform.api.Functions;
import com.platform.api.Logger;
import com.platform.api.Schedulable;

/**
 * To test this class using a REST browser plugin like Poster:<pre>
 *  1. Login to the platform in a browser session. Launch Poster.
 *  2. URL: https://{domain}/networking/rest/class/operation/exec
 *  3. Request type: application/xml
 *  4. Request body:
       <platform>
         <execClass>
            <clazz>com.platform.demo.cron.CronJobDemo</clazz>
            <method>run</method>
         </execClass>
       </platform>
 *  5. POST the request.
 *  6. See the results:
 *     https://{domain}/networking/rest/scheduledJob?fieldList=*   
 */
public class CronJobDemo
{

    /**
     * Schedule a cron job using the DailyTask class.
     *
     * @param Map  Not used. Required for signature to be
     *             callable using class/operation/exec
     */
    public String run(Map params) {
        Logger.info("Scheduling...", "CronJob");
        String msg = "";
        try {
          // Format: "Secs  Mins  Hrs  DayOfMon  Mon  DayOfWk  Yr" 
          // Values: ?="don't care"  a,b=list  a/b=interval  a-b=range
          String cronExp = "0 0 3 ? * * *";   // Run every day at 3 am
          
          Schedulable task = new DailyTask();
          String jobId = Functions.schedule("Daily Task", task, cronExp);
          msg = "Job scheduled";
        }
        catch (Exception e) {
            msg = "Failed: " + e.getMessage();
        }
        Logger.info(msg, "CronJob");
        return msg;
    }
    
    public class DailyTask implements Schedulable
    {
        @Override
        public void execute() {
           // Do important stuff here when the job runs.      
        }   
    }

    

}